@@ -8,23 +8,33 @@
 #' @param save_to_file Required, Boolean, Default is TRUE, but if not, returns result to memory 
 #' 
 #' @return path to output file
+#' 
 #' @export
+#'
 #' @examples \dontrun{
 #' ocrFile(file_path="path_to_ocr_file", output_dir="path_to_output_dir")
 #' }
 
-ocrFile <- function(file_path="", output_dir="./", exportFormat="txt", save_to_file=TRUE) {
+ocrFile <- function(file_path="", output_dir="./", 
+					exportFormat=c("txt", "txtUnstructured", "rtf", "docx", "xlsx", "pptx", "pdfSearchable", "pdfTextAndImages", "pdfa", "xml", "xmlForCorrectedImage", "alto"), 
+					save_to_file=TRUE) {
+
+	exportFormat <- match.arg(exportFormat)
 
 	res <- processImage(file_path=file_path, exportFormat=exportFormat)
 
 	# Wait till the processing is finished with a maximum time 
-	while(!(any(res$id ==listFinishedTasks()$id))) {
+	while(!(any(as.character(res$id) == as.character(listFinishedTasks()$id)))) {
 		Sys.sleep(1)
 	}
 
 	finishedlist <- listFinishedTasks()
+	
+	# Coerce to char. if not.
+	res$id <- as.character(res$id)
+	finishedlist$id <- as.character(finishedlist$id)
 
-	if (!save_to_file) {
+	if (identical(save_to_file, FALSE)) {
 		res <- curl_fetch_memory(finishedlist$resultUrl[res$id == finishedlist$id])
 		return(rawToChar(res$content))
 	}
