@@ -19,11 +19,11 @@ processMRZ <- function(file_path="", ...) {
 	
 	process_details <- abbyy_POST("processMRZ", body=body, ...)
 
-	resdf <- as.data.frame(do.call(rbind, process_details)) # collapse to a data.frame
+	resdf <- ldply(process_details, rbind)
 
 	# Print some important things
 	cat("Status of the task: ", resdf$status, "\n")
 	cat("Task ID: ", 			resdf$id, "\n")
 
-	return(invisible(resdf))
+	resdf
 }
\ No newline at end of file
