@@ -33,5 +33,5 @@ submitImage <- function(file_path="", taskId="", pdfPassword="", ...)
 	cat("Status of the task: ", resdf$status, "\n")
 	cat("Task ID: ", 			resdf$id, "\n")
 
-	return(invisible(resdf))
+	resdf
 }
\ No newline at end of file
