@@ -9,6 +9,6 @@ test_that("getResults works", {
   close(token_file)
   setapp(unlist(strsplit(token, ",")))
 
-  #results <- getResults(save_to_file=FALSE)
-  #expect_that(results, is_a("data.frame"))
+  results <- getResults(save_to_file=FALSE)
+  expect_that(results, is_a("data.frame"))
 })
\ No newline at end of file
